| erri_sensitivity | R Documentation |
Generates random non-negative weights on the simplex and recalculates the index and rank of each unit.
erri_sensitivity(object, R = 1000L, seed = NULL)
object |
An object returned by |
R |
Number of random weight vectors. |
seed |
Optional integer seed. |
A data frame containing sampled weights, indices, and ranks.
fit <- erri(erri_example_data(), "year", "income", 2020, "region")
sens <- erri_sensitivity(fit, R = 100, seed = 3)
head(sens)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.