| plot.erri | R Documentation |
Plots the observed and counterfactual paths with a prediction interval, compares composite indices, or compares component scores.
## S3 method for class 'erri'
plot(x, type = c("trajectory", "index", "components"),
unit = NULL, ...)
x |
An object returned by |
type |
Trajectory, index, or component-score plot. |
unit |
Unit to display for a trajectory; defaults to the first unit. |
... |
Additional arguments passed to the base plotting function. |
The object invisibly.
fit <- erri(erri_example_data(), "year", "income", 2020, "region")
plot(fit, type = "index")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.